import { DriverCapabilities, QueryColumnsResult, QueryOptions, QuerySchemasResult, QueryTablesResult, UnloadOptions } from '@cubejs-backend/base-driver';
import { JDBCDriver, JDBCDriverConfiguration } from '@cubejs-backend/jdbc-driver';
import { DatabricksQuery } from './DatabricksQuery';
export type DatabricksDriverConfiguration = JDBCDriverConfiguration & {
    /**
     * Driver read-only mode flag.
     */
    readOnly?: boolean;
    /**
     * Export bucket type.
     */
    bucketType?: string;
    /**
     * Export bucket path.
     */
    exportBucket?: string;
    /**
     * Export bucket DBFS mount directory.
     */
    exportBucketMountDir?: string;
    /**
     * Poll interval.
     */
    pollInterval?: number;
    /**
     * The export bucket CSV file escape symbol.
     */
    exportBucketCsvEscapeSymbol?: string;
    /**
     * Export bucket AWS account key.
     */
    awsKey?: string;
    /**
     * Export bucket AWS account secret.
     */
    awsSecret?: string;
    /**
     * Export bucket AWS account region.
     */
    awsRegion?: string;
    /**
     * Export bucket Azure account key.
     */
    azureKey?: string;
    /**
     * Databricks catalog name.
     * https://www.databricks.com/product/unity-catalog
     */
    catalog?: string;
    /**
     * Databricks security token (PWD).
     */
    token?: string;
};
type ShowTableRow = {
    database: string;
    tableName: string;
    isTemporary: boolean;
};
/**
 * Databricks driver class.
 */
export declare class DatabricksDriver extends JDBCDriver {
    /**
     * Show warning message flag.
     */
    private showSparkProtocolWarn;
    /**
     * Read-only mode flag.
     */
    protected readonly config: DatabricksDriverConfiguration;
    static dialectClass(): typeof DatabricksQuery;
    /**
     * Returns default concurrency value.
     */
    static getDefaultConcurrency(): number;
    /**
     * Class constructor.
     */
    constructor(conf?: Partial<DatabricksDriverConfiguration> & {
        /**
         * Data source name.
         */
        dataSource?: string;
        /**
         * Max pool size value for the [cube]<-->[db] pool.
         */
        maxPoolSize?: number;
        /**
         * Time to wait for a response from a connection after validation
         * request before determining it as not valid. Default - 10000 ms.
         */
        testConnectionTimeout?: number;
    });
    /**
     * @override
     */
    readOnly(): boolean;
    /**
     * @override
     */
    capabilities(): DriverCapabilities;
    /**
     * @override
     */
    setLogger(logger: any): void;
    /**
     * @override
     */
    loadPreAggregationIntoTable(preAggregationTableName: string, loadSql: string, params: unknown[], _options: any): Promise<unknown[]>;
    /**
     * @override
     */
    query<R = unknown>(query: string, values: unknown[]): Promise<R[]>;
    /**
     * Returns pre-aggregation schema name.
     */
    getPreaggsSchemaName(): string;
    /**
     * @override
     */
    dropTable(tableName: string, options?: QueryOptions): Promise<unknown>;
    showDeprecations(): void;
    /**
     * @override
     */
    protected getCustomClassPath(): Promise<string>;
    /**
     * Execute create schema query.
     */
    createSchemaIfNotExists(schemaName: string): Promise<void>;
    /**
     * Returns the list of the tables for the specified schema.
     */
    getTablesQuery(schemaName: string): Promise<{
        'table_name': string;
    }[]>;
    /**
     * Returns tables meta data object.
     */
    tablesSchema(): Promise<Record<string, Record<string, object>>>;
    /**
     * Returns list of accessible tables.
     */
    getTables(): Promise<ShowTableRow[]>;
    getSchemas(): Promise<QuerySchemasResult[]>;
    getTablesForSpecificSchemas(schemas: QuerySchemasResult[]): Promise<QueryTablesResult[]>;
    getColumnsForSpecificTables(tables: QueryTablesResult[]): Promise<QueryColumnsResult[]>;
    /**
     * Returns table columns types.
     */
    tableColumnTypes(table: string): Promise<{
        name: any;
        type: string;
    }[]>;
    /**
     * Returns query columns types.
     */
    queryColumnTypes(sql: string, params?: unknown[]): Promise<{
        name: any;
        type: string;
    }[]>;
    /**
     * Returns schema full name.
     */
    getSchemaFullName(schema: string): string;
    /**
     * Returns quoted string.
     */
    quoteIdentifier(identifier: string): string;
    /**
     * Returns the JS type by the Databricks type.
     */
    toGenericType(columnType: string): string;
    /**
     * Determines whether export bucket feature is configured or not.
     */
    isUnloadSupported(): Promise<boolean>;
    /**
     * Returns to the Cubestore an object with links to unloaded to an
     * export bucket data.
     */
    unload(tableName: string, options: UnloadOptions): Promise<{
        exportBucketCsvEscapeSymbol: string | undefined;
        csvFile: string[];
        types: {
            name: any;
            type: string;
        }[];
        csvNoHeader: boolean;
    }>;
    /**
     * Unload data from a SQL query to an export bucket.
     */
    private unloadWithSql;
    /**
     * Unload data from a temp table to an export bucket.
     */
    private unloadWithTable;
    /**
     * Returns an array of signed URLs of unloaded csv files.
     */
    private getCsvFiles;
    /**
     * Returns Azure signed URLs of unloaded scv files.
     */
    private getSignedAzureUrls;
    /**
     * Returns S3 signed URLs of unloaded scv files.
     */
    private getSignedS3Urls;
    /**
     * Saves specified query to the configured bucket. This requires Databricks
     * cluster to be configured.
     *
     * For Azure blob storage you need to configure account access key in
     * Cluster -> Configuration -> Advanced options
     * (https://docs.databricks.com/data/data-sources/azure/azure-storage.html#access-azure-blob-storage-directly)
     *
     * `fs.azure.account.key.<storage-account-name>.blob.core.windows.net <storage-account-access-key>`
     *
     * For S3 bucket storage you need to configure AWS access key and secret in
     * Cluster -> Configuration -> Advanced options
     * (https://docs.databricks.com/data/data-sources/aws/amazon-s3.html#access-s3-buckets-directly)
     *
     * `fs.s3a.access.key <aws-access-key>`
     * `fs.s3a.secret.key <aws-secret-key>`
     */
    private createExternalTableFromSql;
    /**
     * Saves specified table to the configured bucket. This requires Databricks
     * cluster to be configured.
     *
     * For Azure blob storage you need to configure account access key in
     * Cluster -> Configuration -> Advanced options
     * (https://docs.databricks.com/data/data-sources/azure/azure-storage.html#access-azure-blob-storage-directly)
     *
     * `fs.azure.account.key.<storage-account-name>.blob.core.windows.net <storage-account-access-key>`
     *
     * For S3 bucket storage you need to configure AWS access key and secret in
     * Cluster -> Configuration -> Advanced options
     * (https://docs.databricks.com/data/data-sources/aws/amazon-s3.html#access-s3-buckets-directly)
     *
     * `fs.s3a.access.key <aws-access-key>`
     * `fs.s3a.secret.key <aws-secret-key>`
     */
    private createExternalTableFromTable;
}
export {};
//# sourceMappingURL=DatabricksDriver.d.ts.map